@@ -91,6 +91,7 @@ class Value(Element):
     @classmethod
     def read(cls, stream: nip.stream.Stream, parser: nip.parser.Parser) -> Value:
         return cls._read_token(tokens.Number, stream) or \
+               cls._read_token(tokens.Bool, stream) or \
                cls._read_token(tokens.String, stream) or \
                cls._read_token(tokens.List, stream) or \
                cls._read_token(tokens.Dict, stream)
@@ -203,8 +204,8 @@ class Tag(Element):
                 args, kwargs = [value], {}
         try:
             return constructor.builders[self.name](*args, **kwargs)
-        except:
-            raise nip.constructor.ConstructorError(self, args, kwargs)
+        except Exception as e:
+            raise nip.constructor.ConstructorError(self, args, kwargs, e)
 
     def dump(self, dumper: nip.dumper.Dumper):
         return f"!{self.name} " + self.value.dump(dumper)
