@@ -27,7 +27,8 @@ class TokenError(Exception):
 class Number(Token):
     @staticmethod
     def read(stream: Stream) -> Tuple[int, Union[int, float]]:
-        pos, string = String.read(stream)
+        string = stream[:].strip()
+        pos = len(string)
         value = None
         for t in (int, float):
             try:
@@ -41,6 +42,23 @@ class Number(Token):
             return 0, 0
 
 
+class Bool(Token):
+    @staticmethod
+    def read(stream: Stream) -> Tuple[int, bool]:
+        string = stream[:].strip()
+        pos = len(string)
+        if string in ['true', 'True', 'yes']:
+            return pos, True
+        if string in ["false", 'False', 'no']:
+            return pos, False
+        return 0, False
+
+
+# class NoneType(Token):
+#     @staticmethod
+#     def read(stream: Stream) -> Tuple[int, Any]:
+#         string = stream[:strip]
+
 class String(Token):
     @staticmethod
     def read(stream: Stream) -> Tuple[int, str]:
@@ -71,7 +89,8 @@ class Name(Token):
         if not stream[pos].isalpha():
             return 0, ''
 
-        while stream[pos].isalnum() or stream[pos] == '_':
+        while stream[pos].isalnum() or stream[pos] == '_' or \
+                stream[pos] == '.':
             pos += 1
 
         return pos, stream[:pos]
